; ANN-GONG 
; by Stefano Tognon
; (C) 2005 Ice Team
; version 1.00

; Well, this game is also dedicated to my "Ann-Gong friend"
; This is my 10 game for C64 

; sprite definitions:
;
; 0 low (multicolor)
; 1 up  (multicolor)
; 2 arm (singlecolor)

; 3 low (multicolor)
; 4 up  (multicolor)
; 5 arm (singlecolor)

       processor 6502

RASTER0   =  82 

JOY_UP    = 1
JOY_DOWN  = 2
JOY_LEFT  = 4
JOY_RIGHT = 8
JOY_FIRE  = 16

ANIM_STEPS = 5        ; steps fo animation walk
ANIM_STEPS2 = 19      ; steps for animation jump

MOVE1_LEFT  = 1
MOVE1_RIGHT = 2
MOVE1_UP    = 3
MOVE1_DN    = 4
FIRE1_RIGHT = 5
FIRE1_LEFT  = 6

MOVE2_LEFT  = 1
MOVE2_RIGHT = 2
MOVE2_UP    = 3
MOVE2_DN    = 4
FIRE2_RIGHT = 5
FIRE2_LEFT  = 6

FIRE1_STEPS = 19       ; step for fire animation (vertical to diagonal up)
FIRE2_STEPS = 19       ; step for fire animation (vertical to diagonal up)

SPD         = 11      ; number of sprites definitions to add for second player
MAXLEVEL    = 10

;ENER_DEC    = $10     ; energy decrement when kicked
RELOAD      = 45      ; reload ticks before to have a new fire action

COL_LIMIT   = $34     ; limit for collision

POSY      = 200       ; y pos of lower sprite
POSX1     = 60        ; x position of actor 1
POSX2     = 220       ; x position of actor 2

POSX2L    = 60+35     ; x pos left for 2
POSX2R    = 180       ; x pos right for 2

X_LEFT_LIM1  = 50      ; left x limit for sprite actor 1
X_RIGHT_LIM1 = 194     ; right x limit for sprite actor 1

SCREEN     = $E536    ; clean the screen with color
SET_COOR   = $E50C    ; set x/y coord
STRING     = $AB1E    ; put a string

joystick   = $03      ; joystick values
animation1 = $04      ; animation flag for left user; <>0 is in animation
step1      = $05      ; step in animation   
indX1      = $06      ; $07
indY1      = $08      ; $09
addr       = $0a      ; $0b
addr2      = $0c      ; $0d
animation2 = $0d      ; animation flag for right user; <>0 is in animation
step2      = $0e      ; step in animation
energy1    = $0f      ; energy actor 1
energy2    = $10      ; energy actor 2
kill       = $11      ; kill flag: 1=actor1 did, 2=actor2 died
level      = $12      ; actual level
reload1    = $13      ; fire reload for actor 1
reload2    = $14      ; fire reload for actor 2

time       = $80      ; time counter
timeDl     = $81      ; time delay counter
aiStep     = $82      ; ai steps 
GO         = $89      ; 1=go
temp1      = $92
temp2      = $93
temp3      = $94



 org 2049
        lda  #0
        jsr  $4000                ; init music

; install custom chars
                                  ; transfer characters codes to 14336
        sei

        lda  #$33
        sta  $01

        ldy #0
        ldx #8
lp1
        lda $d000,y
        sta $3800,y
        dey
        bne lp1
next
        inc lp1+2
        inc lp1+5
        dex
        beq exit
        cpx #$06 ; do not overwrite the predefined chars $3a00-3aff
        beq next
        bne lp1
exit
        lda  #$37
        sta  $01
        cli

        jsr  mirrorSprite


; install interrupt routine
      sei
      lda  #<irqR2
      sta  $0314
      lda  #>irqR2
      sta  $0315
                                 ; disable cia interrupt
      ldx  #$00
      stx  $DC0E                 ; Control register A of CIA #1
      inx
      stx  $D01A                 ; IRQ mask register
      cli
                                 ; use VIC interrupt
      stx  $D019                 ; Interrupt indicator register
      lda  #RASTER2
      sta  $D012                 ; Reading/Writing IRQ balance value
      lda  #$1B
      sta  $D011                 ; VIC control register MCM char mode  
      lda  #$08
      sta  $D016

      jsr  presentation

      ;lda  #$1B
      ;sta  $D011                 ; VIC control register MCM char mode  
      lda  #$18
      sta  $D016

      sei
      lda  #<irqR0
      sta  $0314
      lda  #>irqR0
      sta  $0315

      lda  #RASTER0
      sta  $D012
      cli
                                 ; switch to new chars
      lda  #31
      sta  $D018

      ldx  #11
      stx  53281                 ; set screen color  
      stx  53280

      inx
      stx  $D022                 ; mcm common color 1 

      lda  #15
      sta  $D023                 ; mcm common color 2

                                 ; create the fixed screen
      ;lda  #15
      jsr  SCREEN                ; clearing the screen with color 

      ldy  #0
      sty  $D025                 ; sprite multicolor 0

      ldy  #4
      sty  $D026                 ; sprite multicolor 1

      ldy  #6
      sty  $D027                 ; color sprite 0
      sty  $D028                 ; color sprite 1

      ldy  #2
      sty  $D029                 ; color sprite 2
      sty  $D02C                 ; color sprite 5

      dey
      sty  $D02A                 ; color sprite 3  
      sty  $D02B                 ; color sprite 4 

      lda  #$1B
      sta  $D01C                 ; sprite multicolor

      lda  #$24                  ; x/y expansion for the arm
      sta  $d017
      sta  $d01d

      jsr  copyScreen            ; copy screen
      lda  #$28
      sta  lp1_+2
      lda  #$d8
      sta  lp1__+2
      jsr  copyScreen            ; copy color 


mailLoop:
      ldx  #1
      stx  level                 ; level 1

      dex
      stx  score                 ; clear score
      stx  score+1
      stx  score+2

loopExt:
      ldx  #0                    ; reset animation
      ;stx  animation1
      ;stx  animation2
      stx  kill                  ; no one are killed
      stx  reload1
      stx  reload2

      inx
      inx
      stx  aiStep

      lda  #$99                  ; reset energy
      sta  energy1
      sta  energy2
      sta  time                  ; 99 seconds

      jsr  spriteInit 
      jsr  writeScore            ; write actual score

      jsr  writeFire             ; write fire string 

      jsr  waitFire
      jsr  hideFire             ; hide fire string

      jsr  startAnimation

      ldx  #0                    ; reset animation
      stx  animation1
      stx  animation2

loop:
      jsr  waitIRQ               ; attend a frame of syncronization

      lda  reload1
      beq  skipRL1
      dec  reload1               ; decrement fire reload for actor1
skipRL1:
      lda  reload2
      beq  skipRL2
      dec  reload2               ; decrement fire reload for actor2
skipRL2:

      jsr  makeAnimation1        ; make animation of actor 1
      jsr  makeAnimation2        ; make animation of actor 2

      jsr  enemyAI               ; use AI of enemy: here we are in disadvantage in choosing the actions
      lda  animation1
      bne  skipTestJoy           ; if there is an animation did not test for user action   
      jsr  userAction            ; test for user action
skipTestJoy:


      ;jsr  enemyAI               ; use AI of enemy: here we are in advantage in choosing the actions
      jsr  testCollision         ; test for actor collision

      jsr  decTime               ; decrement the time
      jsr  testScore             ; test if this score is the highscore
      jsr  writeScore            ; write actual score

      lda  kill
      cmp  #1
      bmi  loop
      beq  gameOver

      jsr  died2Animation

      lda  time
      jsr  giveBonus             ; give bonus according with this time
      jsr  hideBonus

      inc  level                 ; go to next level
      lda  level                 ; check if we have win
      cmp  #MAXLEVEL
      beq  win
      jmp  loopExt

win:
      jsr  writeWin              ; write win string
      jsr  writeFire
      jsr  waitFire
      jsr  hideWin               ; hide Win
      
      jmp  mailLoop

gameOver:
      jsr  writeGameOver         ; write game over string
      jsr  died1Animation
      jsr  writeFire
      jsr  waitFire
      jsr  hideOver              ; hide Over
      jmp  mailLoop


waitFire:
releasefire
      jsr  getJoystick           ; check for already pressed fire
      and  #JOY_FIRE
      bne  releasefire
waitFire2                        ; wait a joystick fire action
      jsr  getJoystick
      and  #JOY_FIRE
      beq  waitFire2

;================================
; Make AI of enemy
;================================
enemyAI:
      dec  aiStep
      bne  exitEAI

      lda  #(MAXLEVEL+2)        ; calculate next steps based on the level 
      sec
      sbc  level
      sta  aiStep

      ldx  animation2           ; if there is an animation, skip it 
      bne  exitEAI

      lda  $d006
      sbc  $d000
      cmp  #COL_LIMIT            ; there is collision only if actors are near
      bcs  testGoNear

                                 ; we are near, so attack or defend
      lda  animation1
      beq  attack

                                 ; defend if this is the case
      cmp  #FIRE1_RIGHT
      beq  go_down               ; we must go down to skip up fire

      cmp  #FIRE1_LEFT
      beq  go_up                 ; we must go up to skip down fire

      ldy  reload2
      bne  cantFire

      cmp  #MOVE1_UP             ; fire up if she goes up
      beq  upF

      cmp  #MOVE1_DN             ; fire down if she goes up
      beq  downF
cantFire:
      rts

go_up:                           ; go up animation
      lda  #MOVE2_UP
      sta  animation2
      bne  set_anim

go_down:                         ; go down animation
      lda  #MOVE2_DN
      sta  animation2

set_anim:
      lda  #ANIM_STEPS2
      sta  step2
      rts

testGoNear:                      ; test go near the other actor
      lda  $D006
      sbc  $D000
      bcc  goBehind

goNear:                          ; go near only if not at the min left place
      lda  $D006
      cmp  #POSX2L
      bcc  exitGN

      lda  #MOVE2_LEFT
      sta  animation2
      lda  #ANIM_STEPS
      sta  step2
exitGN:
      rts

goBehind:                        ; go behind only if not at the min right place
      lda  $D006
      cmp  #POSX2R
      bcs  exitGN

      lda  #MOVE2_RIGHT
      sta  animation2
      lda  #ANIM_STEPS
      sta  step2
      rts

attack:
      lda  reload2               ; can't fire again before a reload time
      bne  exitEAI

      jsr  random                ; pick a random number
      asl
      bcc  downF
                                 ; use up fire action
upF:
      lda  #FIRE2_RIGHT
      sta  animation2
      bne  setSt
                                 ; use down fire action
downF:
      lda  #FIRE2_LEFT
      sta  animation2
setSt:
      lda  #FIRE2_STEPS
      sta  step2                 ; step of animation

exitEAI:
      rts

;================================
; copy screen  
;================================
copyScreen:
      ldy #0
      ldx #4
lp1_:
      lda $1C00,y
lp1__:
      sta $0400,y
      dey
      bne lp1_
next_:
      inc lp1_+2
      inc lp1_+5
      dex
      beq exit_ 
      bne lp1_
exit_: 
      rts

;===============================
; Test user action for movements
;===============================
userAction:
      jsr  getJoystick
      and  #JOY_FIRE             ; test for fire pressed
      bne  isFire

      lda  joystick
      and  #JOY_RIGHT            ; test for right movement
      bne  moveRight

      lda  joystick
      and  #JOY_LEFT             ; test for left movement
      bne  moveLeft

      lda  joystick
      and  #JOY_UP               ; test for up movement
      bne  moveUp

      lda  joystick
      and  #JOY_DOWN            ; test for dn movement
      bne  moveDn
      rts

moveRight:
      lda  $d000                 ; look for right limit
      cmp  #X_RIGHT_LIM1
      bcs  exitUA                ; we cannot go more 

      lda  #MOVE1_RIGHT
      sta  animation1            ; allow animation
      lda  #ANIM_STEPS
      sta  step1                 ; step of animation
      rts

moveLeft:
      lda  $d000                 ; look for left limit
      cmp  #X_LEFT_LIM1
      bcc  exitUA                ; we cannot go more

      lda  #MOVE1_LEFT
      sta  animation1            ; allow animation
      lda  #ANIM_STEPS
      sta  step1                 ; step of animation
      rts 

moveUp:
      lda  #MOVE1_UP
      sta  animation1            ; allow animation
      lda  #ANIM_STEPS2
      sta  step1                 ; step of animation
      rts

moveDn:
      lda  #MOVE1_DN
      sta  animation1            ; allow animation
      lda  #ANIM_STEPS2
      sta  step1                 ; step of animation
      rts

isFire:
      lda  reload1               ; can't fire again before a reload time
      bne  exitUA

      lda  joystick
      and  #JOY_RIGHT
      bne  fireRight

      lda  joystick
      and  #JOY_LEFT
      bne  fireLeft
      rts

fireLeft:
      lda  #FIRE1_LEFT
      sta  animation1            ; allow fire down animation
      lda  #FIRE1_STEPS
      sta  step1                 ; step of animation
      rts

fireRight:
      lda  #FIRE1_RIGHT
      sta  animation1            ; allow fire up animation
      lda  #FIRE1_STEPS
      sta  step1                 ; step of animation
exitUA:
      rts 


move1_right:  
      lda  #<walk_sx_dx_x
      sta  indX1
      lda  #>walk_sx_dx_x
      sta  indX1+1
      jmp  setVert

;================================= 
; Make animation of actor 1
;=================================
makeAnimation1:
      lda  animation1
      beq  exitUA

      ; make animation 
      cmp  #MOVE1_DN
      beq  move1_dn

      cmp  #MOVE1_UP
      beq  move1_up

      cmp  #FIRE1_LEFT
      beq  fire1_left

      cmp  #MOVE1_RIGHT
      beq  move1_right

      cmp  #MOVE1_LEFT
      beq  move1_left



      ;cmp  #FIRE1_RIGHT
      ;beq  fire1_right
fire1_right:
      dec  step1                 ; decrement animation 
      lda  step1
      cmp  #(FIRE1_STEPS-1)      ; compare with first animation step
      beq  fire1_1

      cmp  #1                    ; compare to last animation step
      beq  fire1_2
      rts

fire1_1:
      ldx  #SP_BP3               ; use low body part 3
      stx  2040
      ldx  #SP_DU                ; use diagonal up sprite
      stx  2042
      rts

fire1_2:      
      ldx  #SP_VU                ; use vertical up sprite
      stx  2042
      ldx  #(POSY-40)            ; set y positions of bar
      stx  $D005
      ldx  #RELOAD               ; next fire need a reload time
      stx  reload1
      jmp  endAnim

fire1_left:
      dec  step1                 ; decrement animation 
      lda  step1
      cmp  #(FIRE1_STEPS-1)      ; compare with first animation step
      beq  fire1_3

      cmp  #1                    ; compare to last animation step
      beq  fire1_2
      rts

fire1_3:
      ldx  #SP_BP3               ; use low body part 3
      stx  2040
      ldx  #SP_DD                ; use diagonal down sprite
      stx  2042
      ldx  #(POSY-3)            ; set y positions of bar
      stx  $D005
      rts

move1_up:
      ldx  #SP_BP2               ; use low body part 2
      stx  2040

      lda  #<jump_up_y
      sta  indY1
      lda  #>jump_up_y
      sta  indY1+1

      lda  #<jump_up_x
      sta  indX1
      lda  #>jump_up_x
      sta  indX1+1
      jmp  move1

move1_dn:
      ldx  #SP_BP4              ; use low body part 4
      stx  2040

      lda  #<jump_dn_y
      sta  indY1
      lda  #>jump_dn_y
      sta  indY1+1

      lda  #<jump_dn_x
      sta  indX1
      lda  #>jump_dn_x
      sta  indX1+1
      jmp  move1

move1_left: 
      lda  #<walk_dx_sx_x
      sta  indX1
      lda  #>walk_dx_sx_x
      sta  indX1+1  

setVert:
      lda  #<walk_sx_dx_y
      sta  indY1
      lda  #>walk_sx_dx_y
      sta  indY1+1

move1:
      ldx #4

loopINC1:
      ldy  step1
      lda  $D000,x
      clc
      adc  (indX1),y
      sta  $D000,x               ; move in x direction using the given table's step

      ;ldy  step1
      lda  $D001,x
      clc
      adc  (indY1),y
      sta  $D001,x              ; move in y direction using the given table's step

      dex
      dex 
      bpl  loopINC1

      dec  step1
      bpl  skip1
 
endAnim:
      ldx  #SP_BP1               ; use low body part 1
      stx  2040
      lda  #0
      sta  animation1            ; animation is finished
skip1:
      rts  


move2_right:  
      lda  #<walk_sx_dx_x
      sta  indX1
      lda  #>walk_sx_dx_x
      sta  indX1+1
      jmp  setVert2

;================================= 
; Make animation of actor 2
;=================================
makeAnimation2:
      lda  animation2
      beq  skip1

      ; make animation 
      cmp  #MOVE2_DN
      beq  move2_dn

      cmp  #MOVE2_UP
      beq  move2_up

      cmp  #FIRE2_LEFT
      beq  fire2_left

      cmp  #MOVE2_RIGHT
      beq  move2_right

      cmp  #MOVE2_LEFT
      beq  move2_left


      ;cmp  #FIRE2_RIGHT
      ;beq  fire2_right
fire2_right:
      dec  step2                 ; decrement animation 
      lda  step2
      cmp  #(FIRE2_STEPS-1)      ; compare with first animation step
      beq  fire2_1

      cmp  #1                    ; compare to last animation step
      beq  fire2_2
      rts

fire2_1:
      ldx  #SP_BP3+SPD           ; use low body part 3
      stx  2043
      ldx  #SP_DU+SPD            ; use diagonal up sprite
      stx  2045
      rts

fire2_2:      
      ldx  #SP_VU+SPD            ; use vertical up sprite
      stx  2045
      ldx  #(POSY-40)            ; set y positions of bar
      stx  $D00b
      ldx  #RELOAD               ; next fire need a reload time
      stx  reload2
      jmp  endAnim2

fire2_left:
      dec  step2                 ; decrement animation 
      lda  step2
      cmp  #(FIRE2_STEPS-1)      ; compare with first animation step
      beq  fire2_3

      cmp  #1                    ; compare to last animation step
      beq  fire2_2
      rts

fire2_3:
      ldx  #SP_BP3+SPD           ; use low body part 3
      stx  2043
      ldx  #SP_DD+SPD            ; use diagonal down sprite
      stx  2045
      ldx  #(POSY-3)             ; set y positions of bar
      stx  $D00b
      rts

move2_up:
      ldx  #SP_BP2+SPD           ; use low body part 2
      stx  2043

      lda  #<jump_up_y
      sta  indY1
      lda  #>jump_up_y
      sta  indY1+1

      lda  #<jump_up_x
      sta  indX1
      lda  #>jump_up_x
      sta  indX1+1
      jmp  move2

move2_dn:
      ldx  #SP_BP4+SPD           ; use low body part 4
      stx  2043

      lda  #<jump_dn_y
      sta  indY1
      lda  #>jump_dn_y
      sta  indY1+1

      lda  #<jump_dn_x
      sta  indX1
      lda  #>jump_dn_x
      sta  indX1+1
      jmp  move2

move2_left: 
      lda  #<walk_dx_sx_x
      sta  indX1
      lda  #>walk_dx_sx_x
      sta  indX1+1  

setVert2:
      lda  #<walk_sx_dx_y
      sta  indY1
      lda  #>walk_sx_dx_y
      sta  indY1+1

move2:
      ldx #4

loopINC2:
      ldy  step2
      lda  $D006,x
      clc
      adc  (indX1),y
      sta  $D006,x               ; move in x direction using the given table's step

      ;ldy  step2
      lda  $D007,x
      clc
      adc  (indY1),y
      sta  $D007,x               ; move in y direction using the given table's step

      dex
      dex 
      bpl  loopINC2

      dec  step2
      bpl  skip2
 
endAnim2:
      ldx  #SP_BP1+SPD           ; use low body part 1
      stx  2043
      lda  #0
      sta  animation2            ; animation is finished
skip2:
      rts  


;================================
; Collision detect
;================================
testCollision:
      sec        ;;;; eventually remove this for save space
      lda  $d006
      sbc  $d000
      cmp  #COL_LIMIT            ; there is collision only if actors are near
      bcs  exitCol

      ldx  animation1
      ldy  animation2
                                 ; test if actor left is kick actor2
test1:
      cpx  #FIRE1_RIGHT
      bne  test1Left             ; is an up kick?  

      cpy  #MOVE2_DN
      bne  col2                  ; collision only if actor2 is not sitting down
      beq  test2

test1Left:
      cpx  #FIRE1_LEFT
      bne  test2                 ; is an down kick?

      cpy  #MOVE2_UP
      bne  col2                  ; collision only if actor2 is not jumping up
      ;beq  test2

test2:                           ; test if actor right is kick actor1
      cpy  #FIRE2_RIGHT
      bne  test2Left             ; is an up kick?  

      cpx  #MOVE1_DN
      bne  col1                  ; collision only if actor1 is not sitting down
      beq  exitCol

test2Left:
      cpy  #FIRE2_LEFT
      bne  exitCol               ; is an down kick?

      cpx  #MOVE1_UP
      bne  col1                  ; collision only if actor1 is not jumping up
      rts

col2:
      lda  energy2
      cmp  #1
      bcc  kill2
      ;sbc  #ENER_DEC
      ;sta  energy2
      jsr  sub1dec
      sta  energy2
      lda  #1
      jsr  addScore
      jmp  test2                 ; collisions can be simultaned

col1:
      lda  energy1
      cmp  #1
      bcc  kill1
      ;sbc  #ENER_DEC
      ;sta  energy1
      jsr  sub1dec
      sta  energy1
      rts

kill1:                           ; actor 1 died
      lda  #1
      sta  kill
exitCol:
      rts

kill2:                           ; actor 2 died
      lda  #2
      sta  kill
      rts

;=================================
; sub 1 from accumulator in 
; decimal mode
;=================================
sub1dec:
      sed
      sec
      sbc  #$01                   ; sub 1 second (in decimal mode)      
      cld
      rts

;================================
; Write score and energy
;================================
writeScore:
      lda  energy1
      jsr  atoax
      stx  $400+40*19+33
      sta  $400+40*19+34

      lda  energy2
      jsr  atoax
      stx  $400+40*19+37
      sta  $400+40*19+38

      ldx  #$40                  ; show reload effect 
      lda  reload1
      bne  skipR1
      ldx  #$20
skipR1:
      stx  $400+40*19+32

      ldx  #$40
      lda  reload2
      bne  skipR2
      ldx  #$20
skipR2:
      stx  $400+40*19+39

      lda  level                  ; write the level
      jsr  atoax
      sta  $400+40*15+35

      lda  time                   ; write the time
      jsr  atoax
      stx  $400+40*5+38
      sta  $400+40*5+39

      ldx  #0
      jsr  writePoints
      ldx  #3
      jmp  writePoints
      ;rts

;=================================
; write score
; x=0/3 0 for score, 3 for highscore
;=================================
writePoints:
      ldy  #0

      lda  #$71                   ; this is the low address for score ($471)
      cpx  #3
      bne  skipws

      lda  #$99                   ; this is the high address for hiscore ($499)
skipws:
      sta  wra1+1                 ; change low address as needed
      sta  wra2+1

loopws:
      lda  score,x
      pha
      lsr
      lsr
      lsr
      lsr
      ora  #$30
wra1:
      sta  $400+40+2,y
      iny
      pla
      and  #$0F
      ora  #$30
wra2:
      sta  $400+40+3,y
      inx
      iny
      cpy  #6
      bne  loopws
      rts

;=================================
; Write fire string
;=================================
writeFire:
      ldx  #10
      ldy  #32
      jsr  SET_COOR
      lda  #<Sfire
      ldy  #>Sfire
      jmp  STRING                 ; put the name of the game
      ;rts

Sfire:
  .byte 159,"PRESS",157,17,"FIRE",0

;=================================
; Hide the string
;=================================
hideFire:
      ldx  #10
      ldy  #32
      jsr  SET_COOR
      lda  #<Shide
      ldy  #>Shide
      jmp  STRING                 ; put the name of the game
      ;rts

Shide:
  .byte "     ",157,17,"    ",0

;=================================
; Write game over string
;=================================
writeGameOver:
      ldx  #7
      ldy  #32
      jsr  SET_COOR
      lda  #<Sover
      ldy  #>Sover
      jmp  STRING                 ; put the name of the game
      ;rts

Sover:
  .byte 159,"GAME ",157,17,"OVER",0

;=================================
; Write win string
;=================================
writeWin:
      ldx  #7
      ldy  #32
      jsr  SET_COOR
      lda  #<Swin
      ldy  #>Swin
      jmp  STRING                 ; put the name of the game
      ;rts

Swin:
  .byte 159,"YOU  ",157,17,"WIN!",0

;=================================
; Hide the over/win string
;=================================
hideOver:
hideWin:
      ldx  #7
      ldy  #32
      jsr  SET_COOR
      lda  #<Shide
      ldy  #>Shide
      jmp  STRING                 ; put the name of the game
      ;rts

;=================================
; give bonus: time*25 points
;=================================
giveBonus:
      pha
      ldx  #12
      ldy  #9
      jsr  SET_COOR
      lda  #<Sbonus
      ldy  #>Sbonus
      jsr  STRING                 ; put the name of the game
      pla

      tax
loopBonus:
      stx  temp3
      lda  #$20
      jsr  addScore               ; add the score
      jsr  testScore              ; test if this is the high score
      jsr  writeScore
      jsr  waitIRQ
      ldx  temp3
      dex
      bne  loopBonus

      rts

Sbonus:
  .byte 5,"BONUS:  TIME*20",0

;=================================
; hide bonus
;=================================
hideBonus:
      ldx  #12
      ldy  #9
      jsr  SET_COOR
      lda  #<Sbonus_
      ldy  #>Sbonus_
      jsr  STRING
      rts

Sbonus_:
  .byte 155, 96, 96, 96, 96, 96, 96, 96
  .byte 96, 96, 96, 96, 96, 96, 96, 96, 0


;=================================
; add points to score
; A=point to add
;=================================
addScore:
      stx  temp3
      ldx  #2
      ;ldy  #0                     ; clear carry indicator
      sed                         ; decimal mode
      clc
      adc  score,x
      sta  score,x
      bcc  exitscore

      ;iny                         ; carry indicator
      dex
      lda  #0
      adc  score,x
      sta  score,x
      bcc  exitscore

      dex
      lda  #0
      adc  score,x
      sta  score,x
exitscore:
      cld                         ; normal mode

      ;cpy  #0                     ; test carry indicator
      ;beq  skipAS

      ;lda  score+1                ; read middle of score
      ;and  #$3F
      ;cmp  #$40
      ;bne  skipAS                 ; if $40, we have reach another 4000 points

      ;jsr  incLife                ; give another life
skipAS:
      ldx  temp3
      rts


;=================================
; Test if this score must be the
; hiscore
;=================================
testScore:
                                  ; test if we have a new highscore
      lda  score
      cmp  score+3
      bcc  notHS
      bne  setHS

      lda  score+1
      cmp  score+4
      bcc  notHS
      bne  setHS

      lda  score+2
      cmp  score+5
      bcc  notHS
      bne  setHS

notHS:
      rts

setHS:                             ; copy the score to hiscore
      ldx  #3
setHS_:
      lda  score-1,x
      sta  score+2,x
      dex
      bne  setHS_
      beq  notHS

;=================================
; input a=$12 output x= $31 "1" a= $32 "2"
;=================================
atoax:
      pha                      ; save A for lo-nibble fetch
      lsr
      lsr
      lsr
      lsr
      ora  #$30
      tax
      pla                      ;lo-nibble fetch
      and  #$0F
      ora  #$30
      rts

;================================
; set initial sprites
;================================ 
spriteInit:
      lda  #POSY                 ; set y position of low sprite   
      sta  $D001
      sta  $D007

      lda  #(POSY-21)            ; set y position of up sprite   
      sta  $D003
      sta  $D009

      lda  #POSX1                ; set x positions of first actor
      sta  $D000
      sta  $D002
      lda  #(POSX1+20)
      sta  $D004

      lda  #POSX2                ; set x positions of second actor
      sta  $D006
      sta  $D008
      lda  #(POSX2-42)
      sta  $D00A

      lda  #(POSY-40)            ; set y positions of bar
      sta  $D005
      sta  $D00b
                                 ; set sprite pointers for first actor
      ldx  #(SP_BP1)
      stx  2040
      ldx  #SP_UP1
      stx  2041
      ldx  #SP_VU
      stx  2042
                                 ; set sprite pointers for second actor
      ldx  #(SP_BP1+SPD)
      stx  2043
      ldx  #(SP_UP1+SPD)
      stx  2044
      ldx  #(SP_VU+SPD)
      stx  2045

      lda  #$3F
      sta  $D015                 ; sprite enable
      rts

;================================
; Start "hello" animation
;================================
startAnimation:
      ldx  #SP_DU                ; give vertical up bar
      stx  2042
      ldx  #(SP_DU+SPD)
      stx  2045

      ldx  #30                   ; delay
      jsr  delay

      ldx  #SP_UP2               ; use upper body 2
      stx  2041

      ldx  #(SP_UP2+SPD)
      stx  2044

      ldx  #50
      jsr  delay

      ldx  #SP_UP1               ; use upper body 1
      stx  2041
                                 ; set sprite pointers for second actor
      ldx  #(SP_UP1+SPD)
      stx  2044

      ldx  #30
      jsr  delay

      jsr  spriteInit

      rts

;================================
; Make animation for actor 1 died
;================================
died1Animation:
      lda  #POSY                 ; set y position of low sprite   
      sta  $D001

      sta  $D003                 ; set y position of up sprite   

      lda  $d000                 ; position the body at the righ place
      sec
      sbc  #21
      sta  $d000
      lda  #$3B
      sta  $D015                 ; sprite enable


      lda  #(POSY-40)            ; set y positions of bar
      sta  $D00b
                                 ; set sprite pointers for first actor
      ldx  #(SP_KI1)
      stx  2040
      ldx  #(SP_KI2)
      stx  2041
      ldx  #(SP_VU)              ; use vertical bar
      stx  2042
                                 ; give vertical up bar
      ldx  #(SP_DU+SPD)
      stx  2045

      ldx  #30                   ; delay
      jsr  delay
                                 ; use upper body 2
      ldx  #(SP_UP2+SPD)
      stx  2044

      ldx  #50
      jsr  delay
                                 ; use upper body 1
      ldx  #(SP_UP1+SPD)
      stx  2044

      ldx  #30
      jsr  delay
      rts

;================================
; Make animation for actor 2 died
;================================
died2Animation:
      lda  #POSY                 ; set y position of low sprite   
      sta  $D007

      sta  $D009                 ; set y position of up sprite   

      lda  $d006                 ; position the body at the righ place
      clc
      adc  #21
      sta  $d006
      lda  #$1F
      sta  $D015                 ; sprite enable

      lda  #(POSY-40)            ; set y positions of bar
      sta  $D005

                                 ; set sprite pointers for first actor
      ldx  #(SP_KI1+SPD)
      stx  2043
      ldx  #(SP_KI2+SPD)
      stx  2044
      ldx  #(SP_VU+SPD)          ; use vertical bar
      stx  2045

      ldx  #SP_DU                ; give vertical up bar
      stx  2042

      ldx  #30                   ; delay
      jsr  delay

      ldx  #SP_UP2               ; use upper body 2
      stx  2041

      ldx  #50
      jsr  delay

      ldx  #SP_UP1               ; use upper body 1
      stx  2041

      ldx  #30
      jsr  delay
      rts

;================================
; Delay x frames
;================================
delay:
      jsr  waitIRQ
      dex
      bne  delay
      rts


;================================
; Mirror the sprites
;================================
mirrorSprite:
      lda  #<SPRITES
      sta  addr
      lda  #>SPRITES
      sta  addr+1                ; set source sprites address

      lda  #<SP_END
      sta  addr2
      lda  #>SP_END
      sta  addr2+1               ; set destination sprites address

initSpr:
      ldy  #0
      sty  temp3 

loopSpr:
      lda  (addr),y
                                 ; mirror one byte
      ldx  #3
loopMir:
      lsr
      rol  temp3
      lsr
      rol  temp2
      lsr  temp3
      rol  temp2
      dex
      bpl  loopMir

      lda  temp2
      sta  (addr2),y

      ldx  temp3
      cpx  #2
      bne  skipAdj

      ldx  #$ff
      stx  temp3
                                 ; swap the two values
      pha
      dey
      dey  
      lda  (addr2),y
      sta  temp1
      pla
      sta  (addr2),y
      iny
      iny
      lda  temp1
      sta  (addr2),y

skipAdj:
      inc  temp3

      iny
      cpy  #63                   ; all the sprites chars
      bne  loopSpr

      clc                        ; goes to next sprites
      lda  addr
      adc  #64
      sta  addr
      lda  addr+1
      adc  #0
      sta  addr+1

      cmp  #(>SP_END)+1
      beq  exitSI

      clc                        ; goes to next sprites
      lda  addr2
      adc  #64
      sta  addr2
      lda  addr2+1
      adc  #0
      sta  addr2+1


      jmp  initSpr
;exitSI:
      ;rts

;================================
; Get Joystick movement
;================================
getJoystick:
      lda  #$FF
      sta  $DC00
      lda  $DC00
      eor  #$FF
      sta  joystick
exitSI:
      rts

;=================================
; Dec time of 1 sec. after 50
; frames
;=================================
decTime:
      lda  time
      beq  noDecTime
      inc  timeDl
      lda  timeDl
      cmp  #50                    ; 50 frames (pal)=1 second
      bcc  noDecTime
      lda  #$00
      sta  timeDl                 ; reset time frame (delay) conter
      sed
      lda  time
      sec
      sbc  #$01                   ; sub 1 second (in decimal mode)
      sta  time
      cld
noDecTime:
      rts


;================================
; Wait for IRQ before going on
;================================
waitIRQ:
      lda  GO
      beq  waitIRQ
      dec  GO
      rts 

;==================================
; play music, set IRQ1, set graphics
; for scroll
;==================================
irqR0:
      ldx  #1
      stx  $d019                 ; acknowledge the raster interrupt

      lda  #1
      sta  GO     
      jsr  $4003; playMusic

      jmp  $ea81



  org $1C00
 
  incbin "screen.bin" 

  .org $2000 
 
SPRITES:

SP_BP1 = $80
  ; below part 1 (stay)
  .byte 5, 106, 0, 1, 170, 0, 1, 170, 0
  .byte 1, 85, 0, 6, 166, 0, 6, 90, 128
  .byte 22, 170, 128, 26, 154, 160, 26, 150, 160
  .byte 26, 133, 104, 90, 129, 168, 106, 1, 168
  .byte 106, 1, 168, 106, 1, 168, 90, 1, 100
  .byte 25, 0, 80, 20, 0, 96, 120, 1, 112
  .byte 124, 1, 240, 127, 1, 252, 21, 0, 84, 0

SP_BP2 = $81
  ;below part 2 (jump)
  .byte 5, 106, 0, 1, 170, 0, 1, 170, 0
  .byte 1, 85, 0, 6, 166, 0, 6, 90, 128
  .byte 22, 170, 160, 26, 154, 160, 26, 149, 96
  .byte 26, 133, 160, 26, 1, 160, 26, 1, 160
  .byte 26, 1, 160, 26, 1, 160, 26, 1, 160
  .byte 26, 0, 80, 9, 0, 224, 31, 1, 240
  .byte 31, 1, 240, 31, 1, 240, 5, 0, 80, 0
  
SP_BP3 = $82  
  ; below part 3 (fight)
  .byte 5, 106, 0, 1, 170, 0, 1, 170, 0
  .byte 1, 85, 0, 1, 166, 0, 1, 154, 0
  .byte 1, 166, 0, 1, 170, 0, 1, 170, 0
  .byte 1, 106, 128, 1, 106, 128, 0, 106, 128
  .byte 0, 90, 128, 0, 86, 128, 0, 102, 128
  .byte 1, 166, 128, 1, 166, 128, 1, 149, 64
  .byte 7, 223, 240, 7, 223, 240, 5, 85, 80, 0

SP_BP4 = $83  
  ; below part 4 (down)
  .byte 5, 106, 0, 1, 170, 0, 1, 170, 0
  .byte 1, 85, 0, 1, 165, 160, 1, 154, 104
  .byte 1, 170, 154, 0, 106, 166, 3, 218, 166
  .byte 5, 86, 166, 58, 170, 164, 250, 170, 160
  .byte 250, 170, 128, 0, 0, 0, 0, 0, 0
jump_up_x:                                           ; need lot of 0 
jump_dn_x:
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0, 0

SP_UP1 = $84
  ; upper part 1
  .byte 0, 84, 0, 1, 85, 0, 1, 85, 0
  .byte 1, 95, 0, 1, 93, 0, 1, 95, 0
  .byte 5, 127, 0, 5, 124, 0, 20, 240, 0
  .byte 16, 240, 0, 16, 184, 0, 1, 168, 0
  .byte 1, 170, 0, 1, 170, 0, 1, 154, 0
  .byte 1, 154, 0, 1, 154, 80, 6, 149, 172
  .byte 6, 170, 172, 6, 170, 80, 6, 149, 0, 0
  
SP_VU = $85
  ; arm vertical up

  .byte 128, 0, 0, 128, 0, 0, 128, 0, 0
  .byte 128, 0, 0, 128, 0, 0, 128, 0, 0
  .byte 128, 0, 0, 128, 0, 0, 128, 0, 0
  .byte 128, 0, 0, 128, 0, 0, 128, 0, 0 
  .byte 128, 0, 0, 128, 0, 0, 128, 0, 0 
  .byte 128, 0, 0, 128, 0, 0, 128, 0, 0
  .byte 0, 0, 0, 128, 0, 0, 128, 0, 0, 0

  
SP_DU = $86  
  ; arm diagonal up
 ; .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
 ; .byte 0, 0, 0, 0, 0, 0, 0, 3, 0
 ; .byte 0, 6, 0, 0, 12, 0, 0, 24, 0
 ; .byte 0, 48, 0, 0, 96, 0, 0, 192, 0
 ; .byte 1, 128, 0, 3, 0, 0, 6, 0, 0
 ; .byte 12, 0, 0, 24, 0, 0, 48, 0, 0  
 ;.byte 96, 0, 0, 192, 0, 0, 128, 0, 0, 0

  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 12
  .byte 0, 0, 48, 0, 0, 192, 0, 3, 0
  .byte 0, 12, 0, 0, 48, 0, 0, 192, 0
  .byte 3, 0, 0, 12, 0, 0, 48, 0, 0
  .byte 192, 0, 0, 0, 0, 0, 0, 0, 0, 0

SP_DD = $87  
  ; arm diagonal down
  .byte 192, 0, 0, 48, 0, 0, 12, 0, 0
  .byte 3, 0, 0, 0, 192, 0, 0, 48, 0
  .byte 0, 12, 0, 0, 3, 0, 0, 0, 192
  .byte 0, 0, 48, 0, 0, 12, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0, 0

SP_UP2 = $88
  .byte 0, 0, 0, 0, 0, 84, 0, 17, 85
  .byte 0, 21, 85, 0, 5, 95, 0, 1, 95
  .byte 0, 1, 93, 0, 0, 127, 0, 0, 252
  .byte 0, 10, 240, 0, 26, 240, 0, 106, 192
  .byte 0, 106, 128, 1, 106, 128, 1, 154, 128
  .byte 1, 154, 128, 1, 154, 80, 6, 149, 172
  .byte 6, 170, 172, 6, 170, 80, 6, 149, 0, 0

SP_KI1 = $89
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 2, 160
  .byte 0, 10, 170, 20, 42, 170, 95, 41, 85
  .byte 119, 230, 170, 127, 234, 170, 119, 234, 170
  .byte 127, 230, 170, 95, 41, 85, 20, 42, 170
  .byte 16, 26, 170, 64, 6, 165, 0, 1, 80, 0

SP_KI2 = $8a
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 0, 0, 0, 0, 0, 0
  .byte 0, 0, 0, 192, 0, 0, 246, 160, 3
  .byte 154, 170, 171, 166, 170, 175, 154, 90, 191
  .byte 166, 165, 183, 154, 170, 240, 166, 170, 240
  .byte 241, 85, 112, 112, 0, 0, 0, 0, 0, 0

SP_END: 

  .org $2800
  .incbin color.bin

  .org  $3000
; index is decremented to 0  

walk_sx_dx_x:
  .byte $02, $02, $02, $02, $02, $02

walk_sx_dx_y:  
walk_dx_sx_y:  
  .byte $03, $02, $01, $ff, $fe, $fd

walk_dx_sx_x:
  .byte $fe, $fe, $fe, $fe, $fe, $fe

jump_up_y:
  .byte $06, $05, $05, $04, $04, $03, $03, $02, $01, $00, $00, $ff, $fe, $fd, $fd, $fc, $fc, $fb, $fb, $fa

jump_dn_y:
  .byte $f8, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $08

;=================================
; Get a random number 
; routine in publication magazine
;=================================
random:
     inc  Z
     ldy  Z
     lda  $DC04
     eor  $FEDC,y
     eor  $D012
     rts

Z: 
 .byte $00


score:                            ; actual score
  .byte $00, $00, $00

hiScore:                          ; high score
  .byte $00, $00, $00




;==================================
; play music, set IRQ3, set graphics
; modo for logo
; a Bar color by iAN CooG/HokutoForce
; routine is used
;==================================
irqR2:      
      ldx #$00                   ; 2
      lda #25                    ; 2
start0
      cmp $d012                  ; 4
      bne start0                 ; 3
                                 ; [from 4 to 9]
      ldx  #1                    ; 2 [4-5]
      stx  $d019                 ; 4 [6-9] acknowledge the raster interrupt
      lda  #<irqR3               ; 2 [10-11]
      sta  $0314                 ; 4 [12-15]     
      lda  #>irqR3               ; 2 [16-17]    
      sta  $0315                 ; 4 [18-21] 
      lda  #RASTER3              ; 2 [22-23]         
      sta  $D012                 ; 4 [24-27] Reading/Writing IRQ balance value
      
      inc  dummy                 ; 6 [28-33]
      dec  dummy                 ; 6 [34-39]
      inc  dummy                 ; 6 [40-45]
      dec  dummy                 ; 6 [46-51]
      inc  dummy                 ; 6 [52-57]                                   
                                       
loop0
      ldy timer0,x
      lda color0,x
      sta $d020
      sta $d021


delay0
        dey
        bne delay0
        inx
        cpx #16;#(endcolor-color)
        bne loop0

        lda  #0
        sta  53280
        sta  53281 


;rotating raster : down-up
        lda color0
        sta $02
        ldx #00
rotr0   lda color0+1,x
        sta color0  ,x
        inx
        cpx #(endcolor0-color0-1)
        bne rotr0
        lda $02
        sta endcolor0-2                              
      
      ;jsr  playMusic   
      jsr  colorEffect
      jmp  $ea81

;=================================
; set IRQ2, set text mode 
; a Bar color by iAN CooG/HokutoForce
; routine is used
;=================================
irqR3: 
      ldx #$00                   
      lda #$83+8*3               
start:
      cmp $d012                  ; 4 [54-57] [59-62]
      bne start                  ; 3 [58-60] [63-2]
                                 ; -- bad line         
      nop                        ; 2 [3-4]   [9-10]  wait some cycles
      nop                        ; 2 [5-6]   [55-56] to make rasters more stable
      nop                        ; 2 [7-8]   [57-58]
      nop                        ; 2 [9-10]  [59-60]
      nop                        ; 2 [11-55] [61-62] 
      nop                        ; 2 [56-57] [63-1]
loopr3
      ldy timer,x                ; 4 [58-61] [2-5]
      lda color,x                ; 4 [62-3]  [6-9]
      sta $d020                  ; 4 [4-7]   [10-13]
      sta $d021                  ; 4 [8-11]  [14-17]

delayr3
      dey                        ; 2 [12-13] [18-19] 
      bne delayr3                  ; 2 [14-15] [20-21]
                                 ;   ..                       
      inx                        
      cpx #16                    
      bne loopr3                   

      lda  #0
      sta  53280
      sta  53281 
        
;rotating raster : up-down
      lda endcolor-2
      sta $fe
      ldx #(endcolor-color-2)
rotr  lda color-1,x
      sta color  ,x
      dex
      bne rotr
      lda $fe
      sta color

      ldx  #1
      stx  $d019                  ; acknowledge the raster interrupt
          
      
      lda  #<irqR2
      sta  $0314            
      lda  #>irqR2
      sta  $0315
      lda  #RASTER2
      sta  $D012                  ; Reading/Writing IRQ balance value

      jmp  $ea81

color0  ; italian style r00lz;)
       .byte $02,$02,$02,$0a,$00,$02,$0a,$0f,$00
       .byte $02,$0a,$0f,$01,$00,$02,$0a,$0f,$01
       .byte $01,$01,$0f,$0d,$05,$00,$01,$0f,$0d
       .byte $05,$00,$0f,$0d,$05,$00,$0d,$05,$05,$05,$0
endcolor0

timer0:
       .byte $08, $08, $08, $08, $08, $08, $08, $09
       .byte $08, $08, $08, $08, $08, $08, $08, $0a

color  ; italian style r00lz;)
       .byte $02,$02,$02,$0a,$00,$02,$0a,$0f,$00
       .byte $02,$0a,$0f,$01,$00,$02,$0a,$0f,$01
       .byte $01,$01,$0f,$0d,$05,$00,$01,$0f,$0d
       .byte $05,$00,$0f,$0d,$05,$00,$0d,$05,$05,$05,$0
endcolor    
      
timer: .byte $08, $08, $08, $08, $08, $08, $08, $01
       .byte $08, $08, $08, $08, $08, $08, $08, $01


t1:  .byte  "ANN GONG",0
t2:  .byte  "4KB MINIGAME",0
t2_: .byte  "BY  ICE TEAM",0
t3:  .byte  "CREDITS",0
t4:  .byte  "ICE00   CODE, GRAPHICS",0
t5:  .byte  "RICHARD BAYLISS  MUSIC",0
t6:  .byte  "FIRE TO GO",0

presentation:
      lda  #1
      jsr  SCREEN


      ldx  #3
      ldy  #16
      jsr  SET_COOR
      lda  #<t1
      ldy  #>t1
      jsr  STRING                 ; put the name of the game

      ldx  #6
      ldy  #14
      jsr  SET_COOR
      lda  #<t2
      ldy  #>t2
      jsr  STRING                ; put minigame info

      ldx  #9
      ldy  #14
      jsr  SET_COOR
      lda  #<t2_
      ldy  #>t2_
      jsr  STRING                ; put minigame info

      ldx  #17
      ldy  #16
      jsr  SET_COOR
      lda  #<t3
      ldy  #>t3
      jsr  STRING                ; put credits

      ldx  #20
      ldy  #9
      jsr  SET_COOR
      lda  #<t4
      ldy  #>t4
      jsr  STRING                ; put ice

      ldx  #22
      ldy  #9
      jsr  SET_COOR
      lda  #<t5
      ldy  #>t5
      jsr  STRING                ; put richard

      ldx  #24
      ldy  #15
      jsr  SET_COOR
      lda  #<t6
      ldy  #>t6
      jsr  STRING                ; put fire

      jsr  waitFire

      rts

;================================
; Make an animated color effect
;================================
colorEffect:
      ldx  #39
loopCEF:
      lda  colorA,x
      sta  $D800+17*40,x
      sta  $D800+20*40,x
      sta  $D800+22*40,x
      ;sta  $D800+24*40,x
      dex
      bpl  loopCEF

                                  ; rotate colors to left
      lda  colorA
      sta  dummy
                                           
      ldx  #1
      ldy  #0
loopSX:      
      lda  colorA,x
      sta  colorA,y
      inx
      iny
      cpx  #39
      bne  loopSX
      lda  dummy
      sta  colorA,y
      rts

; credits test color effect tables
colorA:
  .byte  1,  1,  1,  1,  1, 13, 13,  3,  3, 15
  .byte 15,  5,  5, 14, 14,  5,  5, 15, 15,  3
  .byte  3, 13, 13,  1,  1,  1,  1,  7,  7,  8
  .byte  8,  2,  2,  8,  8,  7,  7,  1,  1,  1
  
colorB:
  .byte $00

dummy: .byte $00       
;RASTER POSITION FOR GRAPHICS LOGO
RASTER2 =  0
RASTER3 =  150

; secret string
 .byte "ENJOY SID MUSIC AT WWW.HVSC.C64.ORG",0
 .byte "USE REAL 6581/8580 CHIPS...",0
 .byte "LONG LIFE TO THE SID!!!",0




   org $3a00 ; redefined chars are already in place!
char:
CH_SPACE = 32; null char: use the C= one to save some bytes
  ;.byte $00, $00, $00, $00, $00, $00, $00, $00

CH_V1 = 64  
  .byte $aa, $aa, $aa, $aa, $aa, $aa, $aa, $aa
CH_V2 = 65  
  .byte $ff, $ff, $ff, $ff, $ff, $ff, $ff, $ff
CH_L1 = 66  
  .byte $66, $99, $66, $aa, $9a, $aa, $aa, $aa
  .byte $66, $99, $66, $99, $aa, $a6, $aa, $aa
CH_L2 = 68  
  .byte $55, $55, $55, $56, $95, $55, $59, $95
  .byte $55, $56, $55, $59, $95, $55, $65, $59  
CH_L3 = 70  
  .byte $55, $15, $55, $51, $55, $45, $55, $55
  .byte $55, $55, $51, $55, $55, $55, $55, $55
CH_L4 = 72
  .byte $00, $40, $11, $04, $11, $44, $11, $44
  .byte $00, $10, $01, $44, $11, $44, $11, $55
CH_L5 = 74
  .byte $00, $00, $00, $00, $04, $10, $01, $00
  .byte $00, $00, $00, $04, $00, $10, $00, $00

CH_LL = 76  
  .byte $ff, $ff, $ff, $ff, $ff, $ff, $ff, $55
CH_MM = 77  
  .byte $ff, $ff, $ff, $ff, $fd, $f4, $d1, $55  
  .byte $fd, $f6, $d9, $56, $16, $45, $56, $55
  .byte $bf, $af, $5b, $96, $65, $95, $66, $55
  .byte $ff, $ff, $ff, $ff, $bf, $6f, $5b, $55

;CH_A = 81  
;  .byte $24, $a5, $81, $81, $a5, $a5, $81, $81
;CH_N = 82  
;  .byte $81, $81, $a1, $a1, $85, $85, $81, $81
;CH_G = 83  
;  .byte $24, $80, $80, $80, $85, $81, $81, $24
;CH_O = 84  
;  .byte $24, $81, $81, $81, $81, $81, $81, $24


  org $4000
 .incbin kendo_music.bin